@@ -16,22 +16,18 @@
 # under the License.
 from six import string_types
 
-import collections
-
-try:
-    collectionsAbc = collections.abc
-except AttributeError:
-    collectionsAbc = collections
-
+import collections.abc as collectionsAbc
 from glanceclient import client as glance_client
 from heatclient import client as heat_client
 from heatclient import exc as heat_exc
 from ironicclient import client as ironic_client
-from keystoneauth1.identity import generic as ks_id
 from keystoneauth1 import session as ks_session
+from keystoneauth1.exceptions import catalog as catalog_exc
+from keystoneauth1.identity import generic as ks_id
 from novaclient import client as nova_client
 from swiftclient.client import Connection
 from swiftclient import exceptions as swiftexceptions
+from tripleo_validations import constants
 
 
 def get_auth_session(auth_variables):
@@ -85,6 +81,22 @@ def get_ironic_client(auth_variables):
     )
 
 
+def list_plan_and_stack(hclient, swiftclient):
+    try:
+        stacks = [s.stack_name for s in hclient.stacks.list()]
+    except (heat_exc.HTTPNotFound, catalog_exc.EndpointNotFound):
+        return None
+    try:
+        plan_list = []
+        for ac in swiftclient.get_account()[1]:
+            container = swiftclient.get_container(ac['name'])[0]
+            if constants.TRIPLEO_META_USAGE_KEY in container.keys():
+                plan_list.append(ac['name'])
+    except swiftexceptions.ClientException:
+        return None
+    return list(set(stacks).union(plan_list))
+
+
 def filtered(obj):
     """Only return properties of obj whose value can be properly serialized."""
     return {k: v for k, v in obj.__dict__.items()
